import 'dart:async';
import 'package:flutter/material.dart';
import 'widgets/map_widget.dart';
import 'marker_handler/marker_data.dart';
import 'consts.dart';
import 'marker_handler/get_markers.dart';
import 'marker_handler/get_relation.dart';
import 'dart:typed_data';

class DefaultPage extends StatefulWidget {
  const DefaultPage({Key? key}) : super(key: key);

  @override
  _DefaultPageState createState() => _DefaultPageState();
}

class _DefaultPageState extends State<DefaultPage> {
  late Timer _timer;
  bool showBar = false;

  late Future<List<Measurement>> markerListFuture;
  late Future<Uint8List> relationFuture;

  @override
  void initState() {
    super.initState();
    markerListFuture = fetchMarkerData();
    relationFuture = fetchRelation();

    // Schedule fetchMarkerData to run periodically based on fetchInterval from consts
    const Duration interval = Duration(minutes: fetchInterval); // NB fetchInterval value to be determined
    _timer = Timer.periodic(interval, (timer) {
      fetchMarkerData();
    });
  }

  // Fetch-interval timer
  @override
  void dispose() {
    // Cancel timer on widget termination
    _timer.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('IceMap'),
          actions: [
            IconButton(
              icon: const Icon(Icons.search),
              onPressed: () {
                setState(() {
                  showBar = !showBar;
                });
              },
            ),
          ],
        ),
        body: FutureBuilder(
          future: Future.wait([markerListFuture, relationFuture]),
          builder: (BuildContext context, AsyncSnapshot<List<dynamic>> snapshot) {
            // Display loading screen until data is fetched
            if (snapshot.connectionState == ConnectionState.waiting) {
              return const Center(child: CircularProgressIndicator());
            } else if (snapshot.hasError) {
              return Center(child: Text('Error: ${snapshot.error}'));
            } else {
              // Display default page once all data is loaded from server
              List<Measurement> markerList = snapshot.data![0] as List<Measurement>;
              Uint8List relation = snapshot.data![1] as Uint8List;
              return Container( // Return container with list view and background color
                decoration: const BoxDecoration( // Set background color
                  gradient: LinearGradient(
                    begin: Alignment.topCenter,
                    end: Alignment.bottomCenter,
                    colors: [darkBlue, darkestBlue],
                  ),
                ),
                child: ListView(
                  children: [
                    MapContainerWidget(markerList: markerList, relation: relation),
                  ],
                ),
              );
            }
          },
        ),
      ),
    );
  }
}
