import 'dart:typed_data';
import 'package:latlong2/latlong.dart';
import '../marker_handler/marker_data.dart';
import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_maps/maps.dart';

/// A class containing thickness for each subdivision of the map.
class IceThicknessModel {
  IceThicknessModel(this.subDivID, this.thickness);

  final int subDivID;
  final double thickness;
}

/// A stateful widget which contains a choropleth map.
/// The map data is fetched from the server, and the map is rendered
/// using the Syncfusion Flutter Maps library.
class ChoroplethMap extends StatefulWidget {
  const ChoroplethMap({Key? key,
    required this.relation,
    required this.measurements
  }) : super(key: key);

  final Uint8List relation;
  final List<Measurement> measurements;

  @override
  _ChoroplethMapState createState() => _ChoroplethMapState();
}

class _ChoroplethMapState extends State<ChoroplethMap> {
  late MapShapeSource mapShapeSource;
  late final MapZoomPanBehavior _zoomPanBehavior = MapZoomPanBehavior();
  List<IceThicknessModel> iceThicknessList = <IceThicknessModel>[];

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return SfMaps(
        layers: [
          MapShapeLayer(
            source: MapShapeSource.memory(
              widget.relation,
              shapeDataField: 'SubDivID',
            ),
            color: Colors.orange,
            zoomPanBehavior: _zoomPanBehavior,
          ),
        ],
    );
  }
}
